voussoirkit
===========

This is a collection of tools that I use often and import into my other projects.

# Install

`pip install voussoirkit`

## Mirrors

https://github.com/voussoir/voussoirkit

https://gitlab.com/voussoir/voussoirkit

https://codeberg.org/voussoir/voussoirkit
